---
obj: concept
wiki: https://en.wikipedia.org/wiki/ASCII
---

# **American Standard Code for Information Interchange** (ASCII)

ASCII  abbreviated from American Standard Code for Information Interchange, is a character encoding standard for electronic communication. ASCII codes represent text in computers, telecommunications equipment, and other devices ([Binary](../../science/math/Binary%20System.md) to Text). Because of technical limitations of computer systems at the time it was invented, ASCII has just 128 code points, of which only 95 are printable characters, which severely limited its scope. Modern computer systems have evolved to use [Unicode](Unicode.md), which has millions of code points, but the first 128 of these are the same as the ASCII set.

## ASCII Table
| Dec | Hex | Oct | ASCII   |
| --- | --- | --- | ------- |
| 0   | 00  | 000 | `NUL`   |
| 1   | 01  | 001 | `SOH`   |
| 2   | 02  | 002 | `STX`   |
| 3   | 03  | 003 | `ETX`   |
| 4   | 04  | 004 | `EOT`   |
| 5   | 05  | 005 | `ENQ`   |
| 6   | 06  | 006 | `ACK`   |
| 7   | 07  | 007 | `BEL`   |
| 8   | 08  | 010 | `BS`    |
| 9   | 09  | 011 | `HT`    |
| 10  | 0A  | 012 | `LF`    |
| 11  | 0B  | 013 | `VT`    |
| 12  | 0C  | 014 | `FF`    |
| 13  | 0D  | 015 | `CR`    |
| 14  | 0E  | 016 | `SO`    |
| 15  | 0F  | 017 | `SI`    |
| 16  | 10  | 020 | `DLE`   |
| 17  | 11  | 021 | `DC1`   |
| 18  | 12  | 022 | `DC2`   |
| 19  | 13  | 023 | `DC3`   |
| 20  | 14  | 024 | `DC4`   |
| 21  | 15  | 025 | `NAK`   |
| 22  | 16  | 026 | `SYN`   |
| 23  | 17  | 027 | `ETB`   |
| 24  | 18  | 030 | `CAN`   |
| 25  | 19  | 031 | `EM`    |
| 26  | 1A  | 032 | `SUB`   |
| 27  | 1B  | 033 | `ESC`   |
| 28  | 1C  | 034 | `FS`    |
| 29  | 1D  | 035 | `GS`    |
| 30  | 1E  | 036 | `RS`    |
| 31  | 1F  | 037 | `US`    |
| 32  | 20  | 040 | `SP`    |
| 33  | 21  | 041 | `!`     |
| 34  | 22  | 042 | `"`     |
| 35  | 23  | 043 | `#`     |
| 36  | 24  | 044 | `$`     |
| 37  | 25  | 045 | `%`     |
| 38  | 26  | 046 | `&`     |
| 39  | 27  | 047 | `'`     |
| 40  | 28  | 050 | `(`     |
| 41  | 29  | 051 | `)`     |
| 42  | 2A  | 052 | `*`     |
| 43  | 2B  | 053 | `+`     |
| 44  | 2C  | 054 | `,`     |
| 45  | 2D  | 055 | `-`     |
| 46  | 2E  | 056 | `.`     |
| 47  | 2F  | 057 | `/`     |
| 48  | 30  | 060 | `0`     |
| 49  | 31  | 061 | `1`     |
| 50  | 32  | 062 | `2`     |
| 51  | 33  | 063 | `3`     |
| 52  | 34  | 064 | `4`     |
| 53  | 35  | 065 | `5`     |
| 54  | 36  | 066 | `6`     |
| 55  | 37  | 067 | `7`     |
| 56  | 38  | 070 | `8`     |
| 57  | 39  | 071 | `9`     |
| 58  | 3A  | 072 | `:`     |
| 59  | 3B  | 073 | `;`     |
| 60  | 3C  | 074 | `<`     |
| 61  | 3D  | 075 | `=`     |
| 62  | 3E  | 076 | `>`     |
| 63  | 3F  | 077 | `?`     |
| 64  | 40  | 100 | `@`     |
| 65  | 41  | 101 | `A`     |
| 66  | 42  | 102 | `B`     |
| 67  | 43  | 103 | `C`     |
| 68  | 44  | 104 | `D`     |
| 69  | 45  | 105 | `E`     |
| 70  | 46  | 106 | `F`     |
| 71  | 47  | 107 | `G`     |
| 72  | 48  | 110 | `H`     |
| 73  | 49  | 111 | `I`     |
| 74  | 4A  | 112 | `J`     |
| 75  | 4B  | 113 | `K`     |
| 76  | 4C  | 114 | `L`     |
| 77  | 4D  | 115 | `M`     |
| 78  | 4E  | 116 | `N`     |
| 79  | 4F  | 117 | `O`     |
| 80  | 50  | 120 | `P`     |
| 81  | 51  | 121 | `Q`     |
| 82  | 52  | 122 | `R`     |
| 83  | 53  | 123 | `S`     |
| 84  | 54  | 124 | `T`     |
| 85  | 55  | 125 | `U`     |
| 86  | 56  | 126 | `V`     |
| 87  | 57  | 127 | `W`     |
| 88  | 58  | 130 | `X`     |
| 89  | 59  | 131 | `Y`     |
| 90  | 5A  | 132 | `Z`     |
| 91  | 5B  | 133 | `[`     |
| 92  | 5C  | 134 | `\`     |
| 93  | 5D  | 135 | `]`     |
| 94  | 5E  | 136 | `^`     |
| 95  | 5F  | 137 | `_`     |
| 96  | 60  | 140 | `` ` `` |
| 97  | 61  | 141 | `a`     |
| 98  | 62  | 142 | `b`     |
| 99  | 63  | 143 | `c`     |
| 100 | 64  | 144 | `d`     |
| 101 | 65  | 145 | `e`     |
| 102 | 66  | 146 | `f`     |
| 103 | 67  | 147 | `g`     |
| 104 | 68  | 150 | `h`     |
| 105 | 69  | 151 | `i`     |
| 106 | 6A  | 152 | `j`     |
| 107 | 6B  | 153 | `k`     |
| 108 | 6C  | 154 | `l`     |
| 109 | 6D  | 155 | `m`     |
| 110 | 6E  | 156 | `n`     |
| 111 | 6F  | 157 | `o`     |
| 112 | 70  | 160 | `p`     |
| 113 | 71  | 161 | `q`     |
| 114 | 72  | 162 | `r`     |
| 115 | 73  | 163 | `s`     |
| 116 | 74  | 164 | `t`     |
| 117 | 75  | 165 | `u`     |
| 118 | 76  | 166 | `v`     |
| 119 | 77  | 167 | `w`     |
| 120 | 78  | 170 | `x`     |
| 121 | 79  | 171 | `y`     |
| 122 | 7A  | 172 | `z`     |
| 123 | 7B  | 173 | `{`     |
| 124 | 7C  | 174 | `\|`    |
| 125 | 7D  | 175 | `}`     |
| 126 | 7E  | 176 | `~`     |
| 127 | 7F  | 177 | `DEL`   |