---
obj: format
extension: "lrc"
mime: "text/plain"
wiki: https://en.wikipedia.org/wiki/LRC_(file_format)
rev: 2024-03-02
---

# LRC (Timed Lyrics)
**LRC** (short for LyRiCs) is a computer file format that synchronizes song lyrics with an audio file. When an audio file is played with certain music players on a computer or on modern digital audio players, the song lyrics are displayed. The lyrics file generally has the same name as the audio file, with a different filename extension. For example, _**song.mp3**_ and _**song.lrc**_. The LRC format is text-based and similar to subtitle files.

## Format
The Line Time Tags are in the format **\[mm:ss.xx]** where **mm** is minutes, **ss** is seconds and **xx** is hundredths of a second.

**Basic example:**
```lrc
[00:12.00]Line 1 lyrics
[00:17.20]Line 2 lyrics

[00:21.10][00:45.10]Repeating lyrics (e.g. chorus)
...
[mm:ss.xx]last lyrics line
```

**ID tags** may appear before the lyrics, although some players may not recognize or simply ignore this.
```lrc
[ar:_Lyrics artist_]  
[al:_Album where the song is from_]  
[ti:_Lyrics (song) title_]  
[au:_Creator of the Songtext_]
[length:_How long the song is_]
[by:_Creator of the LRC file_]  
[offset:_+/- Overall timestamp adjustment in milliseconds, + shifts time up, - shifts down i.e. a positive value causes lyrics to appear sooner, a negative value causes them to appear later_]  
 
[re:_The player or editor that created the LRC file_]  
[ve:_version of program_]
```

**Example with ID tags:**
```lrc
[ar:Beatles, The]
[al:Hits Of The 60's - Vol. 2]
[ti:Twisted]
[au:Written by Kal Mann / Dave Appell, 1961]
[length: 2:23]

[00:12.00]Naku Penda Piya-Naku Taka Piya-Mpenziwe
[00:15.30]Some more lyrics ...
...
```

## Common tags
- `ti` — Title
- `ar` — Artist
- `al` — Album
- `lr` — Lyricist. Unclear whether that's part of
- `length` — Stated as `m:ss` or `mm:ss` (runtime 10min+) or sometimes also `sss,ms` (hours and minutes factored all into the seconds amount)
- `by` — Person/organization that authored the LRC file
- `tool` — Software used to create LRC file, sometimes also with the software version number and/or a [URL](../internet/URL.md)
